@@ -33,6 +33,7 @@ extern "C" {
 #include "panels/imagebrowserpanel.h"
 #include "panels/messagebrowserpanel.h"
 #include "panels/profilebrowserpanel.h"
+#include "panels/newsbrowserpanel.h"
 
 #include "ui/uiapplicationsettings.h"
 #include <datatypes/message.h>
@@ -41,7 +42,8 @@ extern "C" {
 #define FRIENDS_PAGE 0
 #define IMAGES_PAGE 1
 #define MESSAGES_PAGE 2
-#define MSG_COMPOSER_PAGE 100
+#define NEWS_PAGE 3
+#define MSG_COMPOSER_PAGE 4
 
 #define _MAINICONSIZE_ 64
 
@@ -73,6 +75,7 @@ private:
 
     ImageBrowserPanel *imagesPanel;
     MessageBrowserPanel *messagesPanel;
+    NewsBrowserPanel *newsPanel;
     ProfileBrowserPanel *profilesPanel;
 
     MessageComposer *msgComposer;
@@ -86,6 +89,7 @@ private:
     QAction *msgAction;
     QAction *friendAction;
     QAction *albumAction;
+    QAction *newsAction;
     QAction *moreAction;
 
     void init();
@@ -107,6 +111,7 @@ private slots:
     void onFriendsTriggered();
     void onMessagesTriggered();
     void onAlbumsTriggered();
+    void onNewsTriggered();
     void onMoreTriggered();
 
     void onActionTriggered(QAction*);
@@ -126,6 +131,7 @@ private slots:
 
     void help();
     void about();
+    void statistics();
 
     void orientationChanged();
 
